pub struct UnixDatagram { /* private fields */ }
A Unix datagram socket.

Examples

use unix_socket::UnixDatagram;

let socket = UnixDatagram::bind("/path/to/my/socket").unwrap();
socket.send_to(b"hello world", "/path/to/other/socket").unwrap();
let mut buf = [0; 100];
let (count, address) = socket.recv_from(&mut buf).unwrap();
println!("socket {:?} sent {:?}", address, &buf[..count]);

Implementations

Creates a Unix datagram socket bound to the given path.

Linux provides, as a nonportable extension, a separate “abstract” address namespace as opposed to filesystem-based addressing. If path begins with a null byte, it will be interpreted as an “abstract” address. Otherwise, it will be interpreted as a “pathname” address, corresponding to a path on the filesystem.

Creates a Unix Datagram socket which is not bound to any address.

Create an unnamed pair of connected sockets.

Returns two UnixDatagramss which are connected to each other.

Connects the socket to the specified address.

The send method may be used to send data to the specified address. recv and recv_from will only receive data from that address.

Returns the address of this socket.

Returns the address of this socket’s peer.

The connect method will connect the socket to a peer.

Receives data from the socket.

On success, returns the number of bytes read and the address from whence the data came.

Receives data from the socket.

On success, returns the number of bytes read.

Sends data on the socket to the specified address.

On success, returns the number of bytes written.

Sends data on the socket to the socket’s peer.

The peer address may be set by the connect method, and this method will return an error if the socket has not already been connected.

On success, returns the number of bytes written.

Sets the read timeout for the socket.

If the provided value is None, then recv and recv_from calls will block indefinitely. It is an error to pass the zero Duration to this method.

Sets the write timeout for the socket.

If the provided value is None, then send and send_to calls will block indefinitely. It is an error to pass the zero Duration to this method.

Returns the read timeout of this socket.

Returns the write timeout of this socket.

Moves the socket into or out of nonblocking mode.

Returns the value of the SO_ERROR option.

Shut down the read, write, or both halves of this connection.

This function will cause all pending and future I/O calls on the specified portions to immediately return with an appropriate value (see the documentation of Shutdown).