Struct unix_socket::UnixStream
source · [−]pub struct UnixStream { /* private fields */ }Expand description
A Unix stream socket.
Examples
use unix_socket::UnixStream;
use std::io::prelude::*;
let mut stream = UnixStream::connect("/path/to/my/socket").unwrap();
stream.write_all(b"hello world").unwrap();
let mut response = String::new();
stream.read_to_string(&mut response).unwrap();
println!("{}", response);Implementations
sourceimpl UnixStream
impl UnixStream
sourcepub fn connect<P: AsRef<Path>>(path: P) -> Result<UnixStream>
pub fn connect<P: AsRef<Path>>(path: P) -> Result<UnixStream>
Connects to the socket named by path.
Linux provides, as a nonportable extension, a separate “abstract”
address namespace as opposed to filesystem-based addressing. If path
begins with a null byte, it will be interpreted as an “abstract”
address. Otherwise, it will be interpreted as a “pathname” address,
corresponding to a path on the filesystem.
sourcepub fn pair() -> Result<(UnixStream, UnixStream)>
pub fn pair() -> Result<(UnixStream, UnixStream)>
Creates an unnamed pair of connected sockets.
Returns two UnixStreams which are connected to each other.
sourcepub fn try_clone(&self) -> Result<UnixStream>
pub fn try_clone(&self) -> Result<UnixStream>
Creates a new independently owned handle to the underlying socket.
The returned UnixStream is a reference to the same stream that this
object references. Both handles will read and write the same stream of
data, and options set on one stream will be propogated to the other
stream.
sourcepub fn local_addr(&self) -> Result<SocketAddr>
pub fn local_addr(&self) -> Result<SocketAddr>
Returns the socket address of the local half of this connection.
sourcepub fn peer_addr(&self) -> Result<SocketAddr>
pub fn peer_addr(&self) -> Result<SocketAddr>
Returns the socket address of the remote half of this connection.
sourcepub fn set_read_timeout(&self, timeout: Option<Duration>) -> Result<()>
pub fn set_read_timeout(&self, timeout: Option<Duration>) -> Result<()>
Sets the read timeout for the socket.
If the provided value is None, then read calls will block
indefinitely. It is an error to pass the zero Duration to this
method.
sourcepub fn set_write_timeout(&self, timeout: Option<Duration>) -> Result<()>
pub fn set_write_timeout(&self, timeout: Option<Duration>) -> Result<()>
Sets the write timeout for the socket.
If the provided value is None, then write calls will block
indefinitely. It is an error to pass the zero Duration to this
method.
sourcepub fn read_timeout(&self) -> Result<Option<Duration>>
pub fn read_timeout(&self) -> Result<Option<Duration>>
Returns the read timeout of this socket.
sourcepub fn write_timeout(&self) -> Result<Option<Duration>>
pub fn write_timeout(&self) -> Result<Option<Duration>>
Returns the write timeout of this socket.
sourcepub fn set_nonblocking(&self, nonblocking: bool) -> Result<()>
pub fn set_nonblocking(&self, nonblocking: bool) -> Result<()>
Moves the socket into or out of nonblocking mode.
sourcepub fn take_error(&self) -> Result<Option<Error>>
pub fn take_error(&self) -> Result<Option<Error>>
Returns the value of the SO_ERROR option.